/**
 * @ingroup   browse68_devel
 * @file      SC68browse.h
 * @author    Ben(jamin) Gerard <ben@sashipa.com>
 * @date      1999/02/22
 * @brief     sc68 Browse Info Data Base management
 * @version   $Id: SC68browse.h,v 1.1.1.1 2001/12/24 20:50:10 ben Exp $
 */

/*
 *                 sc68 - Browse Info Data Base management
 *         Copyright (C) 2001 Ben(jamin) Gerard <ben@sashipa.com>
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _SC68BROWSE_H_
#define _SC68BROWSE_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <stdio.h>

/** SC68browse_file_t Flags.
 *  @{
 */
#define SC68BROWSE_YM 1	/**< Yamaha required */
#define SC68BROWSE_MW 2 /**< MicroWire (STE) required */
#define SC68BROWSE_PL 4 /**< Paula (Amiga) required */
/*@}*/

#define SC68BROWSE_HWDEF SC68BROWSE_YM /**< Default HW requirement */

/** BIDB file entry structure. */
typedef struct _sc68browse_struct_
{
  struct _sc68browse_struct_ *nxt; /**< Linked list */
  char   *aname;                   /**< Author string */
  char   *cname;                   /**< Composer string */
  char   *mname;                   /**< Music name */
  char   *path;                    /**< Relative path ( POSIX ) */
  int    time;                     /**< File play time in sec */
  char   flags;                    /**< Hardware flags */
  char   ntrack;                   /**< # of tracks */
} SC68browse_file_t;

/** Browse Info Data Base structure. */
typedef struct
{
  FILE  *f;                        /**< File */
  int   n;                         /**< # Entry (=file) */
  int   nauthor;                   /**< # Author */
  int   ntrack;                    /**< # tracks in all file */
  int   natari;                    /**< # file with ST music */
  int   namiga;                    /**< # file with Amiga music */
  SC68browse_file_t *head;         /**< First entry */
  int   modified;                  /**< any modification since last save ? */
  int   time;                      /**< Browse info total time in sec */
} SC68browse_info_t;

/** Browse info sort criteria enumeration. */
typedef enum
{
  SC68browse_sort_by_author,    /**< sort by author */
  SC68browse_sort_by_composer,  /**< sort by composer */
  SC68browse_sort_by_music,     /**< sort byu music name */
  SC68browse_sort_by_path       /**< sort by file path */
} SC68browse_sort_t;


/** Get current browse info data base.
 */
SC68browse_info_t *SC68browse_getcurrent(void);

/** Init Browse Info.
 *
 *   This functions must be call once at the beginning of the program.
 *   It cleans struct and load Browse info if fname is not nul.
 */
int SC68browse_init(char *fname);

/* Clean exit.
 *
 *    This function must be call at program exit.
 *    It frees memory and cleans internal data.
 */
int SC68browse_kill(void);

/** Check a file in BIDB.
 *
 *     This function try to find a entry matching the following rule :
 *
 *             same path name OR (same author AND same music)
 *
 */
SC68browse_file_t *SC68browse_exist(SC68browse_file_t *model);

/** Del entry from Browse-Info-Data-Base.
 */
SC68browse_file_t *SC68browse_del(SC68browse_file_t *model);

/** Add entry to Browse-Info-Data-Base.
 */
SC68browse_file_t *SC68browse_add(SC68browse_file_t *model);

/* Merge Browse info resource file.
 */
int SC68browse_read(char *fname);

/* Save all Browse info resource file.
 */
int SC68browse_write(char *fname);

/** Sort Browse info list.
 */
int SC68browse_sort(SC68browse_sort_t type);

/** Add or Update entry into Browse Info Data Base.
 */
int SC68browse_update(SC68browse_file_t *be);

/** Verify Browse Info Data Base integrity.
 *
 * @return number of file removed
 */
int SC68browse_verify(void);

/** Generate HTML with current Browse Info.
 */
int SC68browse_generate(char *fname);

#ifdef __cplusplus
}
#endif

#endif /* #ifndef _SC68BROWSE_H_ */
