/**
 * @ingroup   browse68_devel
 * @file      browse68.c
 * @author    Ben(jamin) Gerard <ben@sashipa.com>
 * @date      1999/10/01
 * @brief     sc68 browse info generator
 * @version   $Id: browse68.c,v 1.1.1.1 2001/12/24 20:50:10 ben Exp $
 */

/*
 *                       sc68 - Browse info generator
 *         Copyright (C) 2001 Ben(jamin) Gerard <ben@sashipa.com>
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#include <stdio.h>
#include <string.h>

#include "file68/SC68file.h"
#include "file68/SC68utils.h"
#include "browse68/SC68browse.h"

int SC68browse_update(SC68browse_file_t * be);
int SC68browse_init_bis(FILE * f);
int SC68browse_write_file(FILE * f);

static void help(void)
{
  printf("browse68: sc68 Browse Info Data Base update\n"
	 "        (c) Ben(jamin) Gerard / sashipa <ben@sashipa.com>\n"
	 "Usage : browse68 <bidb-file>  < [-i] sc68-file-1 > [...]\n"
	 "\n"
	 "  bidb-file is loaded as current browse info.\n"
	 "  sc68-files are added to browse info.\n"
	 "  -i option means indirect : next parameteris a one per line list of file.\n"
	 "  if indirect file is '-' then stdin is used.\n"
	 "  final browse info are output to stdout\n" "\n");
}

static int process(char *path)
{
  SC68browse_file_t be;
  music68_t *m;
  disk68_t *d;

  if(!path) return 0;
  if(!path[0]) return 0;
  d = SC68file_load(path);
  if (!d)
    return 0;
  m = d->mus + d->default_six;
  be.aname = m->author;
  be.cname = m->composer;
  be.mname = d->name;
  be.path = path;
  be.time = d->time;
  be.flags = d->flags & 7;
  be.ntrack = d->nb_six;
  SC68browse_update(&be);
  SC68_free(d);
  return 0;
}

/* Should be enought ! */
static char buf[4096];

int main(int na, char **a)
{
  FILE *f;
  char *fname;
  int i;

  if (na < 2) {
    help();
    return 1;
  }
  fname = a[1];
  if (f = SC68_fopen(fname, "rt"), f == NULL) {
    perror("Can't open BIDB file");
    return 2;
  }

  if (SC68browse_init_bis(f) < 0) {
    fclose(f);
    perror("Can't init BIDB");
    return 3;
  }
  fclose(f);

  for (i = 2; i < na; i++) {

    if (a[i][0] == '-' && a[i][1] == 'i') {
      FILE *indirect;
      char *s;

      if (++i >= na)
        break;
      indirect = (a[i][0]=='-' && !a[i][1]) ? stdin : fopen(a[i], "rt");
      if (!indirect)
        continue;
      while (!feof(indirect)) {
      	buf[0] = 0;
      	fname = fgets(buf, sizeof(buf), indirect);
      	if (fname) {
      	  s = strchr(fname, '\n');
      	  if (s)
      	    *s = 0;
      	  process(fname);
      	}
      }
      if (indirect != stdin)
        fclose(indirect);
    } else {
      process(a[i]);
    }

  }
  SC68browse_write_file(stdout);
  return 0;
}

/*
 * functions below are part of ugly hack for linking purpose !!!
 */
int SC68beos_alert(char n)
{
  return 0;
}

