/**
 * @ingroup   desa68_devel
 * @author    Ben(jamin) Gerard <ben@sashipa.com>
 * @file      desa68.h
 * @date      17/03/1999
 * @brief     Motorola 68K disassembler
 * @version   $Id: desa68.h,v 1.3 2001/12/29 17:44:23 Administrator Exp $
 */

/*
 *                        sc68 - 68000 disassembler
 *         Copyright (C) 2001 Ben(jamin) Gerard <ben@sashipa.com>
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#ifndef _DESA68_H_
#define _DESA68_H_

#ifdef __cplusplus
extern "C" {
#endif

#ifndef EMU68DEBUG
#define EMU68DEBUG
#endif

#define DESA68_SYMBOL_FLAG  (1<<0)  /**< Disassemble with symbol */

#define DESA68_INST (1<<0)  /**< Valid instruction */
#define DESA68_BRA  (1<<1)  /**< Branch always instruction */
#define DESA68_BSR  (1<<2)  /**< Subroutine / Conditionnal branch instruction */
#define DESA68_RTS  (1<<3)  /**< Return from subroutine/Interruption instruction */
#define DESA68_INT  (1<<4)  /**< Interrupt instruction (trap, chk) instruction */ 
#define DESA68_NOP  (1<<5)  /**< nop instruction */ 

/** 68K disassemble pass parameters.
 *
 *    The DESA68parm_t data structure contains the information necessary to
 *    disassemble 68K instructions.
 *    - mem68 and memmsk define 68K memory buffer.
 *    - pc is the address of instruction to disassemble in 68K memory. It is
 *      incremented to next instruction by disassembler.
 *    - str and strmax define string receiving disassembly instruction.
 *    - others fields are for internal use only.
 */
typedef struct
{
  unsigned char *mem;     /**< Base of 68K memory                */
  unsigned int  memmsk;   /**< Size of memory - 1 (mask)         */
  unsigned int  pc;       /**< Offset to area to disassemble     */
  int w;                  /**< Last word decoded (sign extended) */
  int flags;              /**< Disassemble options */

  char *str;    /**< Destination string */
  int  strmax;	/**< Destination maximum size in byte */
  char *s;		  /**< Pointer to current destination char @internal */

  unsigned int immsym_min;  /**< Min val to interpret immediat as symbol */
  unsigned int immsym_max;  /**< Max val to interpret immediat as symbol */

  unsigned int ea_src;  /**< Effective address of source operand */
  unsigned int ea_dst;  /**< Effective address of destination operand */

  unsigned int status; /**< DESA68_INST | DESA68_BRA | DESA68_BSR | DESA68_RTS */
  unsigned int branch; /**< Branch or interrupt vector address */

  /* Intermediat opcode decoding */
  int	reg0;       /**< @internal */
  int	reg9;       /**< @internal */
  int	mode3;      /**< @internal */
  int	mode6;      /**< @internal */
  int	opsz;       /**< @internal */
  int	line;       /**< @internal */
  int	adrmode0;   /**< @internal */
  int	adrmode6;   /**< @internal */
  int	szchar;     /**< @internal */
  unsigned int ea;/**< @internal Temporary result for get_ea() */ 

} DESA68parm_t;

/** Disassemble a single 68000 instruction.
 *
 *    param  d  Pointer to disassemble pass parameter structure.
 */
void desa68(DESA68parm_t *d);

#ifdef __cplusplus
}
#endif

#endif /* #ifndef _DESA68_H_ */
