/**
 * @ingroup   file68_devel
 * @file      SC68error.c
 * @author    Ben(jamin) Gerard <ben@sashipa.com>
 * @date      1998/09/08
 * @brief     sc68 error message handling
 * @version   $Id: SC68error.c,v 1.1.1.1 2001/12/24 20:50:10 ben Exp $
 */

/*
 *                      sc68 - Error message handling
 *         Copyright (C) 2001 Ben(jamin) Gerard <ben@sashipa.com>
 *
 *  This program is free software; you can redistribute it and/or modify it
 *  under the terms of the GNU General Public License as published by the
 *  Free Software Foundation; either version 2 of the License, or (at your
 *  option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

#define MAXERROR    8
#define MAXERRORSTR 256

#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "file68/SC68error.h"

static char err[MAXERROR][MAXERRORSTR];
static int nerr = 0;

/* Push error message ( printf format )
 */
int SC68error_add(char *format, ...)
{
  va_list list;
  int n;

  if (nerr < MAXERROR)
    n = nerr++;
  else {
    memmove(err[0], err[1], MAXERRORSTR * (MAXERROR - 1));
    n = MAXERROR - 1;
  }
  va_start(list, format);
  vsprintf(err[n], format, list);
  va_end(list);

  return (int) ((0xDEAD << (sizeof(int) * 8 - 16)) | (rand() & 0xFFF));
}

/* Pop error message
 * => NULL if no message stacked )
 */
char *SC68error_get(void)
{
  if (nerr <= 0) {
    nerr = 0;
    return 0;			/*"SC68 no more error"; */
  }
  return err[--nerr];
}
